==> rocSPARSE-6.3.3.tar.gz: rocSPARSE-rocm-6.3.3/library/src/precond/rocsparse_gtsv_interleaved_batch.hpp <==
/*! \file */
/* ************************************************************************
 * Copyright (C) 2021-2024 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */

#pragma once

#include "control.h"
#include "utility.h"

namespace rocsparse
{
    template <typename T>
    rocsparse_status gtsv_interleaved_batch_buffer_size_template(rocsparse_handle handle,
                                                                 rocsparse_gtsv_interleaved_alg alg,
                                                                 rocsparse_int                  m,
                                                                 const T*                       dl,
                                                                 const T*                       d,
                                                                 const T*                       du,
                                                                 const T*                       x,
                                                                 rocsparse_int batch_count,
                                                                 rocsparse_int batch_stride,
                                                                 size_t*       buffer_size);

    template <typename T>
    rocsparse_status gtsv_interleaved_batch_template(rocsparse_handle               handle,
                                                     rocsparse_gtsv_interleaved_alg alg,
                                                     rocsparse_int                  m,
                                                     T*                             dl,
                                                     T*                             d,
                                                     T*                             du,
                                                     T*                             x,
                                                     rocsparse_int                  batch_count,
                                                     rocsparse_int                  batch_stride,
                                                     void*                          temp_buffer);
}

==> rocSPARSE-7.0.2.tar.gz: rocSPARSE-rocm-7.0.2/library/src/precond/rocsparse_gtsv_interleaved_batch.hpp <==
/*! \file */
/* ************************************************************************
 * Copyright (C) 2021-2025 Advanced Micro Devices, Inc. All rights Reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 *
 * ************************************************************************ */

#pragma once

#include "rocsparse_control.hpp"
#include "rocsparse_utility.hpp"

namespace rocsparse
{
    template <typename T>
    rocsparse_status gtsv_interleaved_batch_buffer_size_template(rocsparse_handle handle,
                                                                 rocsparse_gtsv_interleaved_alg alg,
                                                                 rocsparse_int                  m,
                                                                 const T*                       dl,
                                                                 const T*                       d,
                                                                 const T*                       du,
                                                                 const T*                       x,
                                                                 rocsparse_int batch_count,
                                                                 rocsparse_int batch_stride,
                                                                 size_t*       buffer_size);

    template <typename T>
    rocsparse_status gtsv_interleaved_batch_template(rocsparse_handle               handle,
                                                     rocsparse_gtsv_interleaved_alg alg,
                                                     rocsparse_int                  m,
                                                     T*                             dl,
                                                     T*                             d,
                                                     T*                             du,
                                                     T*                             x,
                                                     rocsparse_int                  batch_count,
                                                     rocsparse_int                  batch_stride,
                                                     void*                          temp_buffer);
}
